@@ -16,6 +16,7 @@
 import os
 
 from oslo_config import cfg
+from oslo_log import log as logging
 
 from neutron.agent.linux import ip_lib
 from neutron.agent.linux import utils
@@ -24,6 +25,7 @@ from neutron.plugins.common import constants
 from neutron_vpnaas._i18n import _
 from neutron_vpnaas.services.vpn.device_drivers import ipsec
 
+LOG = logging.getLogger(__name__)
 TEMPLATE_PATH = os.path.dirname(os.path.abspath(__file__))
 
 strongswan_opts = [
@@ -78,9 +80,16 @@ class StrongSwanProcess(ipsec.BaseSwanProcess):
     def __init__(self, conf, process_id, vpnservice, namespace):
         self.DIALECT_MAP['v1'] = 'ikev1'
         self.DIALECT_MAP['v2'] = 'ikev2'
+        self.DIALECT_MAP['sha256'] = 'sha256'
+        self._strongswan_piddir = self._get_strongswan_piddir()
+        LOG.debug("strongswan piddir is '%s'" % (self._strongswan_piddir))
         super(StrongSwanProcess, self).__init__(conf, process_id,
                                                 vpnservice, namespace)
 
+    def _get_strongswan_piddir(self):
+        return utils.execute(
+            cmd=[self.binary, "--piddir"], run_as_root=True).strip()
+
     def _check_status_line(self, line):
         """Parse a line and search for status information.
 
@@ -104,8 +113,8 @@ class StrongSwanProcess(ipsec.BaseSwanProcess):
         ip_wrapper = ip_lib.IPWrapper(namespace=self.namespace)
         return ip_wrapper.netns.execute(
             [NS_WRAPPER,
-             '--mount_paths=/etc:%s/etc,/var/run:%s/var/run' % (
-                 self.config_dir, self.config_dir),
+             '--mount_paths=/etc:%s/etc,%s:%s/var/run' % (
+                 self.config_dir, self._strongswan_piddir, self.config_dir),
              '--cmd=%s' % ','.join(cmd)],
             check_exit_code=check_exit_code,
             extra_ok_codes=extra_ok_codes)
