@@ -15,13 +15,14 @@
 import contextlib
 
 import mock
-from neutron.common import constants
 from neutron import context
 from neutron import manager
 from neutron.plugins.common import constants as p_constants
 from neutron.tests.unit.db import test_agentschedulers_db
 from neutron.tests.unit.extensions import test_agent as test_agent_ext_plugin
 
+from neutron_lib import constants as lib_constants
+
 from neutron_vpnaas.db.vpn import vpn_validator
 from neutron_vpnaas.services.vpn.service_drivers import ipsec as ipsec_driver
 from neutron_vpnaas.tests.unit.db.vpn import test_vpn_db as test_db_vpnaas
@@ -99,7 +100,7 @@ class TestVPNDriverPlugin(test_db_vpnaas.TestVpnaas,
                     with self.router() as router:
                         plugin = manager.NeutronManager.get_plugin()
                         agent = {'host': FAKE_HOST,
-                                 'agent_type': constants.AGENT_TYPE_L3,
+                                 'agent_type': lib_constants.AGENT_TYPE_L3,
                                  'binary': 'fake-binary',
                                  'topic': 'fake-topic'}
                         plugin.create_or_update_agent(self.adminContext, agent)
